"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const ws_1 = __importDefault(require("ws"));
const events_1 = require("events");
const client_1 = __importDefault(require("./client"));
const https_1 = __importDefault(require("https"));
const http_1 = __importDefault(require("http"));
const telnet_1 = __importDefault(require("./telnet"));
class WTServer extends events_1.EventEmitter {
    constructor(host, port, secure) {
        super();
        this.clients = new Map();
        let server;
        if (secure !== undefined) {
            server = https_1.default.createServer(secure);
        }
        else {
            server = http_1.default.createServer();
        }
        this._server = new ws_1.default.Server({
            server,
        });
        this._server.on("listening", () => this.emit("listening", host, port));
        this._server.on("connection", (socket) => {
            let client = new client_1.default(socket);
            const uuid = client.UUID;
            this.clients.set(client.UUID, client);
            client.on("close", (code, reason) => {
                this.clients.delete(uuid);
                client = null;
            });
            this.emit("connection", client);
        });
        this._server.on("error", (err) => this.emit("error", err));
        server.listen(port, host);
    }
    on(event, listener) {
        return super.on(event, listener);
    }
    emit(event, ...args) {
        return super.emit(event, ...args);
    }
}
(function (WTServer) {
    WTServer.WTClient = client_1.default;
    WTServer.Telnet = telnet_1.default;
})(WTServer || (WTServer = {}));
module.exports = WTServer;
